@@ -11,8 +11,8 @@ pub use header::*;
 mod message_type;
 pub use message_type::*;
 
-mod operation_code;
-pub use operation_code::*;
+mod opcode_value;
+pub use opcode_value::*;
 
 cfg_any_resolver! {
     mod query_writer;
@@ -26,11 +26,11 @@ pub use question::*;
 
 pub mod reader;
 
-mod response_code;
-pub use response_code::*;
+mod rcode_value;
+pub use rcode_value::*;
 
-mod record_class;
-pub use record_class::*;
+mod class_value;
+pub use class_value::*;
 
-mod record_type;
-pub use record_type::*;
+mod type_value;
+pub use type_value::*;
